%define anolis_release 1

%global protobuf_ver 3.20.2
Name:           onnx
Version:        1.15.0
Release:        %{anolis_release}%{?dist}
Summary:        Open Neural Network Exchange
License:        Apache

URL:            https://github.com/onnx/onnx
Source0:        https://github.com/onnx/onnx/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires:  doxygen cmake gcc-c++
BuildRequires:  python3-devel python3-setuptools
# use onnx recommend protobuf version
BuildRequires:  protobuf-devel = %{protobuf_ver} python3-protobuf = %{protobuf_ver}
BuildRequires:  pybind11-devel python3-pytest-runner

Requires:       wget python3-protobuf = %{protobuf_ver}

%description
Open Neural Network Exchange

%package devel
Summary: Development files for onnx
Requires: %{name} = %{version}-%{release}

%description devel
This package contains development files for onnx.


%package python3
Summary: Python files for onnx
Requires: %{name} = %{version}-%{release}

%description python3
This package contains python files for onnx.


%prep
%setup -q
# external libraries
rm -rf third_party/benchmark
rm -rf third_party/pybind11


%build
# python3
for f in `find . -name '*.py'`;
do
  sed -i -e 's|#!/usr/bin/env python|#!/usr/bin/python3|' $f
done

# flags
export CMAKE_ARGS="-DCMAKE_VERBOSE_MAKEFILE:BOOL=ON -DCMAKE_INSTALL_PREFIX:PATH=/usr -DBUILD_SHARED_LIBS:BOOL=ON -DCMAKE_SKIP_RPATH=ON -DCMAKE_VERBOSE_MAKEFILE=OFF -DCMAKE_BUILD_TYPE=RelWithDebInfo"

%{__python3} setup.py build %{?_smp_mflags}


%install
rm -rf %{buildroot}

pushd .setuptools-cmake-build
make install DESTDIR=%{buildroot}
popd

export CMAKE_ARGS="-DCMAKE_VERBOSE_MAKEFILE:BOOL=ON -DCMAKE_INSTALL_PREFIX:PATH=/usr -DBUILD_SHARED_LIBS:BOOL=ON -DCMAKE_SKIP_RPATH=ON -DCMAKE_VERBOSE_MAKEFILE=OFF -DCMAKE_BUILD_TYPE=RelWithDebInfo"
%{__python3} setup.py install --root %{buildroot}

# fix binaries
mkdir -p %{buildroot}/%{_bindir}/
sed -i '1 i #!/usr/bin/python3' %{buildroot}/%{python3_sitearch}/onnx/bin/checker.py
mv -f %{buildroot}/%{python3_sitearch}/onnx/bin/checker.py %{buildroot}/%{_bindir}/
sed -i '1 i #!/usr/bin/python3' %{buildroot}/%{python3_sitearch}/onnx/tools/net_drawer.py
mv -f %{buildroot}/%{python3_sitearch}/onnx/tools/net_drawer.py  %{buildroot}/%{_bindir}/
mv -f %{buildroot}/%{python3_sitearch}/onnx/tools/replace_constants.py %{buildroot}/%{_bindir}/
mv -f %{buildroot}/%{python3_sitearch}/onnx/tools/update_model_dims.py %{buildroot}/%{_bindir}/
rm -rf %{buildroot}/%{python3_sitearch}/onnx/bin %{buildroot}/%{python3_sitearch}/onnx/tools
chmod +x %{buildroot}/%{_bindir}/*

# remove C & headers from python
find %{buildroot}/%{python3_sitearch} -type f -regex '.*\.\(h\|c\|cc\)' -exec rm -rf {} \;
for d in `find %{buildroot}/%{python3_sitearch} -type d -empty`
do
  rm -rf $d | true
done

# fix cmake path
sed -i -e 's|/lib/|/%{_lib}/|g' %{buildroot}/%{_libdir}/cmake/ONNX/ONNXTargets-*.cmake


%files
%doc README.md
%license LICENSE
%{_bindir}/*
%{_libdir}/lib*.so*

%files devel
%{_includedir}/*
%{_libdir}/cmake/*

%files python3
%{python3_sitearch}/*


%changelog
* Mon May 06 2024 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.15.0-1
- update to 1.15.0 to fix CVE-2024-27318

* Wed Dec 27 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.14.0-3
- rebuild with protobuf-3.20.2

* Mon Dec 25 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.14.0-2
- fix import error

* Fri Jun 16 2023 forrest_ly <flin@linux.alibaba.com> - 1.14.0-1 
- init for anolis 23
